@@ -3,11 +3,13 @@ import numpy as np
 import pandas as pd
 import os
 import json
+from functools import lru_cache
 
 def save_pkl(data, dest):
     with open(dest, 'wb') as f:
         pickle.dump(data, f)
 
+@lru_cache(500)
 def load_pkl(dest):
     try:
         with open(dest, 'rb') as f:
@@ -56,9 +58,11 @@ class QuickDB:
         return list(load_pkl(os.path.join(self.path, 'fs/200012')).keys())
 
     def getIDX(self):
-        return load_pkl(os.path.join(self.path, 'ts/IDX.data'))
+        idx = load_pkl(os.path.join(self.path, 'ts/IDX.data'))
+        idx.index = idx.index.map(lambda x : x.strftime("%Y%m%d"))
+        return idx
     
-    def getBdays(self, stringify=False, inverted=False):
+    def getBdays(self, stringify=True, inverted=False):
         if stringify:
             _ = self.getIDX().index.map(lambda x : x.strftime("%Y%m%d"))
         else:
